Class: TransferZero::Document

Inherits:
Object
  • Object
show all
Defined in:
lib/transferzero-sdk/models/document.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Document

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/transferzero-sdk/models/document.rb', line 109

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TransferZero::Document` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TransferZero::Document`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'sender_id')
    self.sender_id = attributes[:'sender_id']
  end

  if attributes.key?(:'upload')
    self.upload = attributes[:'upload']
  end

  if attributes.key?(:'upload_file_name')
    self.upload_file_name = attributes[:'upload_file_name']
  end

  if attributes.key?(:'metadata')
    self. = attributes[:'metadata']
  end

  if attributes.key?(:'upload_content_type')
    self.upload_content_type = attributes[:'upload_content_type']
  end

  if attributes.key?(:'upload_file_size')
    self.upload_file_size = attributes[:'upload_file_size']
  end

  if attributes.key?(:'category')
    self.category = attributes[:'category']
  end

  if attributes.key?(:'side')
    self.side = attributes[:'side']
  end

  if attributes.key?(:'document_type')
    self.document_type = attributes[:'document_type']
  end

  if attributes.key?(:'issuing_country')
    self.issuing_country = attributes[:'issuing_country']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'errors')
    if (value = attributes[:'errors']).is_a?(Hash)
      self.errors = value
    end
  end
end

Instance Attribute Details

#categoryObject

uncategorised



33
34
35
# File 'lib/transferzero-sdk/models/document.rb', line 33

def category
  @category
end

#document_typeObject

This is a brief description of the document type



39
40
41
# File 'lib/transferzero-sdk/models/document.rb', line 39

def document_type
  @document_type
end

#errorsObject

The fields that have some problems and don’t pass validation



47
48
49
# File 'lib/transferzero-sdk/models/document.rb', line 47

def errors
  @errors
end

#idObject

Returns the value of attribute id.



44
45
46
# File 'lib/transferzero-sdk/models/document.rb', line 44

def id
  @id
end

#issuing_countryObject

Issuing country of ID in 2-character alpha ISO 3166-2 country format



42
43
44
# File 'lib/transferzero-sdk/models/document.rb', line 42

def issuing_country
  @issuing_country
end

#metadataObject

Metadata of document



26
27
28
# File 'lib/transferzero-sdk/models/document.rb', line 26

def 
  
end

#sender_idObject

Returns the value of attribute sender_id.



17
18
19
# File 'lib/transferzero-sdk/models/document.rb', line 17

def sender_id
  @sender_id
end

#sideObject

The side of the KYC ID. One of ‘front’ or ‘back’



36
37
38
# File 'lib/transferzero-sdk/models/document.rb', line 36

def side
  @side
end

#uploadObject

Base64 encoded data uri of an image/pdf file or a fully qualified url



20
21
22
# File 'lib/transferzero-sdk/models/document.rb', line 20

def upload
  @upload
end

#upload_content_typeObject

Returns the value of attribute upload_content_type.



28
29
30
# File 'lib/transferzero-sdk/models/document.rb', line 28

def upload_content_type
  @upload_content_type
end

#upload_file_nameObject

Name of the upload



23
24
25
# File 'lib/transferzero-sdk/models/document.rb', line 23

def upload_file_name
  @upload_file_name
end

#upload_file_sizeObject

Returns the value of attribute upload_file_size.



30
31
32
# File 'lib/transferzero-sdk/models/document.rb', line 30

def upload_file_size
  @upload_file_size
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/transferzero-sdk/models/document.rb', line 72

def self.attribute_map
  {
    :'sender_id' => :'sender_id',
    :'upload' => :'upload',
    :'upload_file_name' => :'upload_file_name',
    :'metadata' => :'metadata',
    :'upload_content_type' => :'upload_content_type',
    :'upload_file_size' => :'upload_file_size',
    :'category' => :'category',
    :'side' => :'side',
    :'document_type' => :'document_type',
    :'issuing_country' => :'issuing_country',
    :'id' => :'id',
    :'errors' => :'errors'
  }
end

.openapi_typesObject

Attribute type mapping.



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/transferzero-sdk/models/document.rb', line 90

def self.openapi_types
  {
    :'sender_id' => :'String',
    :'upload' => :'String',
    :'upload_file_name' => :'String',
    :'metadata' => :'Object',
    :'upload_content_type' => :'String',
    :'upload_file_size' => :'Integer',
    :'category' => :'String',
    :'side' => :'String',
    :'document_type' => :'String',
    :'issuing_country' => :'String',
    :'id' => :'String',
    :'errors' => :'Hash<String, Array<ValidationErrorDescription>>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/transferzero-sdk/models/document.rb', line 210

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      sender_id == o.sender_id &&
      upload == o.upload &&
      upload_file_name == o.upload_file_name &&
       == o. &&
      upload_content_type == o.upload_content_type &&
      upload_file_size == o.upload_file_size &&
      category == o.category &&
      side == o.side &&
      document_type == o.document_type &&
      issuing_country == o.issuing_country &&
      id == o.id &&
      errors == o.errors
end

#[](key) ⇒ Object



327
328
329
# File 'lib/transferzero-sdk/models/document.rb', line 327

def [](key)
  to_hash[key]
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
# File 'lib/transferzero-sdk/models/document.rb', line 265

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = TransferZero.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



339
340
341
342
343
344
345
346
347
348
349
350
351
# File 'lib/transferzero-sdk/models/document.rb', line 339

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Returns the model itself

Returns:

  • (Object)

    Returns the model itself



244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'lib/transferzero-sdk/models/document.rb', line 244

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#dig(*args) ⇒ Object



331
332
333
# File 'lib/transferzero-sdk/models/document.rb', line 331

def dig(*args)
  to_hash.dig(*args)
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


229
230
231
# File 'lib/transferzero-sdk/models/document.rb', line 229

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



235
236
237
# File 'lib/transferzero-sdk/models/document.rb', line 235

def hash
  [sender_id, upload, upload_file_name, , upload_content_type, upload_file_size, category, side, document_type, issuing_country, id, errors].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



175
176
177
178
179
180
181
182
183
184
185
186
# File 'lib/transferzero-sdk/models/document.rb', line 175

def list_invalid_properties
  invalid_properties = Array.new
  if @upload.nil?
    invalid_properties.push('invalid value for "upload", upload cannot be nil.')
  end

  if @upload_file_name.nil?
    invalid_properties.push('invalid value for "upload_file_name", upload_file_name cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



311
312
313
# File 'lib/transferzero-sdk/models/document.rb', line 311

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



317
318
319
320
321
322
323
324
325
# File 'lib/transferzero-sdk/models/document.rb', line 317

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  ::ActiveSupport::HashWithIndifferentAccess.new(hash)
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



305
306
307
# File 'lib/transferzero-sdk/models/document.rb', line 305

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



190
191
192
193
194
195
196
# File 'lib/transferzero-sdk/models/document.rb', line 190

def valid?
  return false if @upload.nil?
  return false if @upload_file_name.nil?
  side_validator = EnumAttributeValidator.new('String', ["front", "back"])
  return false unless side_validator.valid?(@side)
  true
end