Class: TransferZero::PayinMethodDetails

Inherits:
Object
  • Object
show all
Defined in:
lib/transferzero-sdk/models/payin_method_details.rb

Overview

Fields needed by the payment processor. Depends on the chose payin type. See the appropriate model details for more info: - NGN::Bank: see [PayinMethodDetailsNGNBank](#model-PayinMethodDetailsNGNBank) - GHS::Mobile: see [PayinMethodDetailsMobile](#model-PayinMethodDetailsMobile) - UGX::Mobile: see [PayinMethodDetailsMobile](#model-PayinMethodDetailsMobile) - TZS::Mobile: see [PayinMethodDetailsMobile](#model-PayinMethodDetailsMobile) Note that some payin processors don’t require additional input, these include paga through NGN::Mobile, lhv through EUR::Bank and GBP::Bank. Some providers like providus also have all of their fields set as optional, so you might not want to set any values. To use these providers please set this value to ‘{}` (an empty hash)

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ PayinMethodDetails

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/transferzero-sdk/models/payin_method_details.rb', line 60

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TransferZero::PayinMethodDetails` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TransferZero::PayinMethodDetails`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'payment_method')
    self.payment_method = attributes[:'payment_method']
  end

  if attributes.key?(:'redirect_url')
    self.redirect_url = attributes[:'redirect_url']
  end

  if attributes.key?(:'phone_number')
    self.phone_number = attributes[:'phone_number']
  end

  if attributes.key?(:'send_instructions')
    self.send_instructions = attributes[:'send_instructions']
  end
end

Instance Attribute Details

#payment_methodObject

The payment method which the user will use to make the payments. Options are bank, card or you can leave empty to support both.



19
20
21
# File 'lib/transferzero-sdk/models/payin_method_details.rb', line 19

def payment_method
  @payment_method
end

#phone_numberObject

The phone number where the funds should be collected from



25
26
27
# File 'lib/transferzero-sdk/models/payin_method_details.rb', line 25

def phone_number
  @phone_number
end

#redirect_urlObject

This is where the user should be redirected back when the payment has been finished



22
23
24
# File 'lib/transferzero-sdk/models/payin_method_details.rb', line 22

def redirect_url
  @redirect_url
end

#send_instructionsObject

States whether to send out the instructions to the phone number on how to pay the funds or not. This shuold always be set to true, otherwise the sender might not receive a prompt for payment.



28
29
30
# File 'lib/transferzero-sdk/models/payin_method_details.rb', line 28

def send_instructions
  @send_instructions
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
# File 'lib/transferzero-sdk/models/payin_method_details.rb', line 31

def self.attribute_map
  {
    :'payment_method' => :'payment_method',
    :'redirect_url' => :'redirect_url',
    :'phone_number' => :'phone_number',
    :'send_instructions' => :'send_instructions'
  }
end

.openapi_one_ofObject

List of class defined in oneOf (OpenAPI v3)



51
52
53
54
55
56
# File 'lib/transferzero-sdk/models/payin_method_details.rb', line 51

def self.openapi_one_of
  [
  :'PayinMethodDetailsMobile',
  :'PayinMethodDetailsNGNBank'
  ]
end

.openapi_typesObject

Attribute type mapping.



41
42
43
44
45
46
47
48
# File 'lib/transferzero-sdk/models/payin_method_details.rb', line 41

def self.openapi_types
  {
    :'payment_method' => :'String',
    :'redirect_url' => :'String',
    :'phone_number' => :'String',
    :'send_instructions' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



126
127
128
129
130
131
132
133
# File 'lib/transferzero-sdk/models/payin_method_details.rb', line 126

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      payment_method == o.payment_method &&
      redirect_url == o.redirect_url &&
      phone_number == o.phone_number &&
      send_instructions == o.send_instructions
end

#[](key) ⇒ Object



235
236
237
# File 'lib/transferzero-sdk/models/payin_method_details.rb', line 235

def [](key)
  to_hash[key]
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/transferzero-sdk/models/payin_method_details.rb', line 173

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = TransferZero.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'lib/transferzero-sdk/models/payin_method_details.rb', line 247

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Returns the model itself

Returns:

  • (Object)

    Returns the model itself



152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/transferzero-sdk/models/payin_method_details.rb', line 152

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#dig(*args) ⇒ Object



239
240
241
# File 'lib/transferzero-sdk/models/payin_method_details.rb', line 239

def dig(*args)
  to_hash.dig(*args)
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


137
138
139
# File 'lib/transferzero-sdk/models/payin_method_details.rb', line 137

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



143
144
145
# File 'lib/transferzero-sdk/models/payin_method_details.rb', line 143

def hash
  [payment_method, redirect_url, phone_number, send_instructions].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



92
93
94
95
96
97
98
99
# File 'lib/transferzero-sdk/models/payin_method_details.rb', line 92

def list_invalid_properties
  invalid_properties = Array.new
  if @phone_number.nil?
    invalid_properties.push('invalid value for "phone_number", phone_number cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



219
220
221
# File 'lib/transferzero-sdk/models/payin_method_details.rb', line 219

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



225
226
227
228
229
230
231
232
233
# File 'lib/transferzero-sdk/models/payin_method_details.rb', line 225

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  ::ActiveSupport::HashWithIndifferentAccess.new(hash)
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



213
214
215
# File 'lib/transferzero-sdk/models/payin_method_details.rb', line 213

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
# File 'lib/transferzero-sdk/models/payin_method_details.rb', line 103

def valid?
  return false if @phone_number.nil?
  _one_of_found = false
  openapi_one_of.each do |_class|
    _one_of = TransferZero.const_get(_class).build_from_hash(self.to_hash)
    if _one_of.valid?
      if _one_of_found?
        return false
      else
        _one_of_found = true
      end
    end
  end

  if !_one_of_found?
    return false
  end

  true
end