Class: TransferZero::PayoutMethodDetailsUSDBank

Inherits:
Object
  • Object
show all
Defined in:
lib/transferzero-sdk/models/payout_method_details_usd_bank.rb

Overview

Nigeria: “‘JSON "details": { "first_name": "Jane", "last_name": "Doe", "phone_number": "+2341234567", // E.164 international format "bank_code": "057", "bank_account": "1234567890", "country": "NG" } “` See [USD Bank](docs.transferzero.com/docs/payout-details/#usdbank) documentation for the bank_code and country lists United States: “`JSON "details": { "first_name": "Jane", "last_name": "Doe", "bank_account": "1234567890", "bank_account_type": "20", // 10 for Savings, 20 for Checking "bank_name": "US Bank", "routing_number": "091000022", "swift_code": "USBKUS44IMT", "country": "US" } See [USD Bank](docs.transferzero.com/docs/payout-details/#usdbank-1) documentation Egypt: “`JSON "details": { "first_name": "Jane", "middle_name": "Jill", // optional "last_name": "Doe", "street": "1 Main Street", "phone_number": "+201023456789", "iban": "EG380019000500000000263180002", "transfer_reason": "personal_account", } “` See [USD Bank](docs.transferzero.com/docs/payout-details/#usdbank-2) documentation

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ PayoutMethodDetailsUSDBank

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/transferzero-sdk/models/payout_method_details_usd_bank.rb', line 88

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TransferZero::PayoutMethodDetailsUSDBank` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TransferZero::PayoutMethodDetailsUSDBank`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'first_name')
    self.first_name = attributes[:'first_name']
  end

  if attributes.key?(:'middle_name')
    self.middle_name = attributes[:'middle_name']
  end

  if attributes.key?(:'last_name')
    self.last_name = attributes[:'last_name']
  end

  if attributes.key?(:'phone_number')
    self.phone_number = attributes[:'phone_number']
  end

  if attributes.key?(:'bank_code')
    self.bank_code = attributes[:'bank_code']
  end

  if attributes.key?(:'bank_account')
    self. = attributes[:'bank_account']
  end

  if attributes.key?(:'bank_account_type')
    self. = attributes[:'bank_account_type']
  end

  if attributes.key?(:'bank_name')
    self.bank_name = attributes[:'bank_name']
  end

  if attributes.key?(:'routing_number')
    self.routing_number = attributes[:'routing_number']
  end

  if attributes.key?(:'swift_code')
    self.swift_code = attributes[:'swift_code']
  end

  if attributes.key?(:'iban')
    self.iban = attributes[:'iban']
  end

  if attributes.key?(:'street')
    self.street = attributes[:'street']
  end

  if attributes.key?(:'transfer_reason')
    self.transfer_reason = attributes[:'transfer_reason']
  end

  if attributes.key?(:'country')
    self.country = attributes[:'country']
  end
end

Instance Attribute Details

#bank_accountObject

Returns the value of attribute bank_account.



28
29
30
# File 'lib/transferzero-sdk/models/payout_method_details_usd_bank.rb', line 28

def 
  @bank_account
end

#bank_account_typeObject

Returns the value of attribute bank_account_type.



30
31
32
# File 'lib/transferzero-sdk/models/payout_method_details_usd_bank.rb', line 30

def 
  @bank_account_type
end

#bank_codeObject

Returns the value of attribute bank_code.



26
27
28
# File 'lib/transferzero-sdk/models/payout_method_details_usd_bank.rb', line 26

def bank_code
  @bank_code
end

#bank_nameObject

Returns the value of attribute bank_name.



32
33
34
# File 'lib/transferzero-sdk/models/payout_method_details_usd_bank.rb', line 32

def bank_name
  @bank_name
end

#countryObject

Returns the value of attribute country.



44
45
46
# File 'lib/transferzero-sdk/models/payout_method_details_usd_bank.rb', line 44

def country
  @country
end

#first_nameObject

Returns the value of attribute first_name.



18
19
20
# File 'lib/transferzero-sdk/models/payout_method_details_usd_bank.rb', line 18

def first_name
  @first_name
end

#ibanObject

Returns the value of attribute iban.



38
39
40
# File 'lib/transferzero-sdk/models/payout_method_details_usd_bank.rb', line 38

def iban
  @iban
end

#last_nameObject

Returns the value of attribute last_name.



22
23
24
# File 'lib/transferzero-sdk/models/payout_method_details_usd_bank.rb', line 22

def last_name
  @last_name
end

#middle_nameObject

Returns the value of attribute middle_name.



20
21
22
# File 'lib/transferzero-sdk/models/payout_method_details_usd_bank.rb', line 20

def middle_name
  @middle_name
end

#phone_numberObject

Returns the value of attribute phone_number.



24
25
26
# File 'lib/transferzero-sdk/models/payout_method_details_usd_bank.rb', line 24

def phone_number
  @phone_number
end

#routing_numberObject

Returns the value of attribute routing_number.



34
35
36
# File 'lib/transferzero-sdk/models/payout_method_details_usd_bank.rb', line 34

def routing_number
  @routing_number
end

#streetObject

Returns the value of attribute street.



40
41
42
# File 'lib/transferzero-sdk/models/payout_method_details_usd_bank.rb', line 40

def street
  @street
end

#swift_codeObject

Returns the value of attribute swift_code.



36
37
38
# File 'lib/transferzero-sdk/models/payout_method_details_usd_bank.rb', line 36

def swift_code
  @swift_code
end

#transfer_reasonObject

Returns the value of attribute transfer_reason.



42
43
44
# File 'lib/transferzero-sdk/models/payout_method_details_usd_bank.rb', line 42

def transfer_reason
  @transfer_reason
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/transferzero-sdk/models/payout_method_details_usd_bank.rb', line 47

def self.attribute_map
  {
    :'first_name' => :'first_name',
    :'middle_name' => :'middle_name',
    :'last_name' => :'last_name',
    :'phone_number' => :'phone_number',
    :'bank_code' => :'bank_code',
    :'bank_account' => :'bank_account',
    :'bank_account_type' => :'bank_account_type',
    :'bank_name' => :'bank_name',
    :'routing_number' => :'routing_number',
    :'swift_code' => :'swift_code',
    :'iban' => :'iban',
    :'street' => :'street',
    :'transfer_reason' => :'transfer_reason',
    :'country' => :'country'
  }
end

.openapi_typesObject

Attribute type mapping.



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/transferzero-sdk/models/payout_method_details_usd_bank.rb', line 67

def self.openapi_types
  {
    :'first_name' => :'String',
    :'middle_name' => :'String',
    :'last_name' => :'String',
    :'phone_number' => :'String',
    :'bank_code' => :'String',
    :'bank_account' => :'String',
    :'bank_account_type' => :'PayoutMethodBankAccountTypeEnum',
    :'bank_name' => :'String',
    :'routing_number' => :'String',
    :'swift_code' => :'String',
    :'iban' => :'String',
    :'street' => :'String',
    :'transfer_reason' => :'PayoutMethodTransferReasonEnum',
    :'country' => :'PayoutMethodCountryEnum'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/transferzero-sdk/models/payout_method_details_usd_bank.rb', line 188

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      first_name == o.first_name &&
      middle_name == o.middle_name &&
      last_name == o.last_name &&
      phone_number == o.phone_number &&
      bank_code == o.bank_code &&
       == o. &&
       == o. &&
      bank_name == o.bank_name &&
      routing_number == o.routing_number &&
      swift_code == o.swift_code &&
      iban == o.iban &&
      street == o.street &&
      transfer_reason == o.transfer_reason &&
      country == o.country
end

#[](key) ⇒ Object



307
308
309
# File 'lib/transferzero-sdk/models/payout_method_details_usd_bank.rb', line 307

def [](key)
  to_hash[key]
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
# File 'lib/transferzero-sdk/models/payout_method_details_usd_bank.rb', line 245

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = TransferZero.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



319
320
321
322
323
324
325
326
327
328
329
330
331
# File 'lib/transferzero-sdk/models/payout_method_details_usd_bank.rb', line 319

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Returns the model itself

Returns:

  • (Object)

    Returns the model itself



224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
# File 'lib/transferzero-sdk/models/payout_method_details_usd_bank.rb', line 224

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#dig(*args) ⇒ Object



311
312
313
# File 'lib/transferzero-sdk/models/payout_method_details_usd_bank.rb', line 311

def dig(*args)
  to_hash.dig(*args)
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


209
210
211
# File 'lib/transferzero-sdk/models/payout_method_details_usd_bank.rb', line 209

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



215
216
217
# File 'lib/transferzero-sdk/models/payout_method_details_usd_bank.rb', line 215

def hash
  [first_name, middle_name, last_name, phone_number, bank_code, , , bank_name, routing_number, swift_code, iban, street, transfer_reason, country].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/transferzero-sdk/models/payout_method_details_usd_bank.rb', line 160

def list_invalid_properties
  invalid_properties = Array.new
  if @first_name.nil?
    invalid_properties.push('invalid value for "first_name", first_name cannot be nil.')
  end

  if @last_name.nil?
    invalid_properties.push('invalid value for "last_name", last_name cannot be nil.')
  end

  if @country.nil?
    invalid_properties.push('invalid value for "country", country cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



291
292
293
# File 'lib/transferzero-sdk/models/payout_method_details_usd_bank.rb', line 291

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



297
298
299
300
301
302
303
304
305
# File 'lib/transferzero-sdk/models/payout_method_details_usd_bank.rb', line 297

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  ::ActiveSupport::HashWithIndifferentAccess.new(hash)
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



285
286
287
# File 'lib/transferzero-sdk/models/payout_method_details_usd_bank.rb', line 285

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



179
180
181
182
183
184
# File 'lib/transferzero-sdk/models/payout_method_details_usd_bank.rb', line 179

def valid?
  return false if @first_name.nil?
  return false if @last_name.nil?
  return false if @country.nil?
  true
end