Class: TransferZero::MandatesApi
- Inherits:
-
Object
- Object
- TransferZero::MandatesApi
- Defined in:
- lib/transferzero-sdk/api/mandates_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_mandate(mandate_id, opts = {}) ⇒ MandateResponse
Fetch a single mandate Finds and returns a Mandate created within the current calendar year, where the mandate is linked to a Recipient owned by the authenticated API key.
-
#get_mandate_with_http_info(mandate_id, opts = {}) ⇒ Array<(MandateResponse, Fixnum, Hash)>
Fetch a single mandate Finds and returns a Mandate created within the current calendar year, where the mandate is linked to a Recipient owned by the authenticated API key.
-
#initialize(api_client = ApiClient.default) ⇒ MandatesApi
constructor
A new instance of MandatesApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ MandatesApi
Returns a new instance of MandatesApi.
19 20 21 |
# File 'lib/transferzero-sdk/api/mandates_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/transferzero-sdk/api/mandates_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_mandate(mandate_id, opts = {}) ⇒ MandateResponse
Fetch a single mandate Finds and returns a Mandate created within the current calendar year, where the mandate is linked to a Recipient owned by the authenticated API key. Returns 404 if the mandate is not owned by the API key or was not issued in the current calendar year — mandates are only valid for the year in which they were issued.
29 30 31 32 |
# File 'lib/transferzero-sdk/api/mandates_api.rb', line 29 def get_mandate(mandate_id, opts = {}) data, _status_code, _headers = get_mandate_with_http_info(mandate_id, opts) data end |
#get_mandate_with_http_info(mandate_id, opts = {}) ⇒ Array<(MandateResponse, Fixnum, Hash)>
Fetch a single mandate Finds and returns a Mandate created within the current calendar year, where the mandate is linked to a Recipient owned by the authenticated API key. Returns 404 if the mandate is not owned by the API key or was not issued in the current calendar year — mandates are only valid for the year in which they were issued.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/transferzero-sdk/api/mandates_api.rb', line 39 def get_mandate_with_http_info(mandate_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: MandatesApi.get_mandate ...' end # verify the required parameter 'mandate_id' is set if @api_client.config.client_side_validation && mandate_id.nil? fail ArgumentError, "Missing the required parameter 'mandate_id' when calling MandatesApi.get_mandate" end # resource path local_var_path = '/mandates/{Mandate ID}'.sub('{' + 'Mandate ID' + '}', mandate_id.to_s) # query parameters query_params = {} # header parameters header_params = {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = {} # http body (model) post_body = nil auth_names = ['AuthorizationKey', 'AuthorizationNonce', 'AuthorizationSecret', 'AuthorizationSignature'] data, status_code, headers = @api_client.call_api(:GET, local_var_path, :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => 'MandateResponse') if @api_client.config.debugging @api_client.config.logger.debug "API called: MandatesApi#get_mandate\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |